@@ -3,12 +3,12 @@ Masks functions
 """
 
 from __future__ import annotations
+from typing import List, Sequence
 
 from vsutil import depth, iterate, get_depth, get_y, get_peak_value, scale_value, Dither, Range
 from .util import _ex_planes
 from .misc import retinex
 from math import sqrt
-from typing import List
 import vapoursynth as vs
 core = vs.core
 
@@ -45,7 +45,8 @@ def comb_mask(src: vs.VideoNode,
               mthresh: int = 9,
               expand: bool = True,
               metric: int = 0,
-              planes: int = 0) -> vs.VideoNode:
+              planes: int | Sequence[int] | None = None
+              ) -> vs.VideoNode:
     """
     Comb mask from TIVTC/TFM plugin.
 
@@ -58,6 +59,11 @@ def comb_mask(src: vs.VideoNode,
                    Metric 1 is from Donald Graft's decomb.dll.
     :param planes: Planes to process.
     """
+    cth_max = 65025 if metric else 255
+    if (cthresh > cth_max) or (cthresh < 0):
+        raise ValueError(f'comb_mask: cthresh must be between 0 and {cth_max} when metric = {metric}.')
+    if (mthresh > 255) or (mthresh < 0):
+        raise ValueError('comb_mask: mthresh must be between 0 and 255.')
 
     peak = get_peak_value(src)
     ex_m0 = [f'x[0,-2] a! x[0,-1] b! x c! x[0,1] d! x[0,2] e! '
@@ -72,11 +78,17 @@ def comb_mask(src: vs.VideoNode,
     ex_spatial = ex_m1 if metric else ex_m0
 
     spatial_mask = src.akarin.Expr(_ex_planes(src, ex_spatial, planes))
+    if (mthresh == 0):
+        if not expand:
+            return spatial_mask
+        return spatial_mask.std.Maximum(planes=planes, coordinates=[0, 0, 0, 1, 1, 0, 0, 0])
+
     motion_mask = core.akarin.Expr([src, src[0] + src], _ex_planes(src, ex_motion, planes))
     motion_mask = motion_mask.std.Maximum(planes=planes, coordinates=[0, 1, 0, 0, 0, 0, 1, 0])
     comb_mask = core.akarin.Expr([spatial_mask, motion_mask], 'x y min')
     if not expand:
         return comb_mask
+
     return comb_mask.std.Maximum(planes=planes, coordinates=[0, 0, 0, 1, 1, 0, 0, 0])
 
 
